@@ -1,4 +1,5 @@
 #' Number of half-lives past
+#' @family decay corrections
 #' @description Given a percentage reduction in activity, calculate how many
 #'   half-lives have passed.
 #' @param pct_lost Percentage of activity lost since reference time.
@@ -7,9 +8,7 @@
 #' dk_pct_to_num_half_life(93.75)
 #' @export
 dk_pct_to_num_half_life <- function(pct_lost){
-  -log(1 - pct_lost / 100) / log(2)
+  if(!is.numeric(pct_lost)) 
+    stop("pct_lost must be a number.")
+    -log(1 - pct_lost / 100) / log(2)
 }
-
-
-
-
